Struct google_firebase1_beta1::api::AddGoogleAnalyticsRequest [−][src]
There is no detailed description.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- add google analytics projects (request)
Fields
analytics_account_id: Option<String>The ID for the existing Google Analytics account that you want to link with the FirebaseProject. Specifying this field will provision a new Google Analytics property in your Google Analytics account and associate the new property with the FirebaseProject.
analytics_property_id: Option<String>The ID for the existing Google Analytics property that you want to associate with the FirebaseProject.