pub struct AnalyticsDetails {
pub analytics_property: Option<AnalyticsProperty>,
pub stream_mappings: Option<Vec<StreamMapping>>,
}Expand description
There is no detailed description.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- get analytics details projects (response)
Fields
analytics_property: Option<AnalyticsProperty>The Analytics Property object associated with the specified FirebaseProject. This object contains the details of the Google Analytics property associated with the Project.
stream_mappings: Option<Vec<StreamMapping>>- For
AndroidAppsandIosApps: a map ofapptostreamIdfor each Firebase App in the specifiedFirebaseProject. EachappandstreamIdappears only once. - ForWebApps: a map ofapptostreamIdandmeasurementIdfor eachWebAppin the specifiedFirebaseProject. Eachapp,streamId, andmeasurementIdappears only once.