pub struct AnalyticsProperty {
pub analytics_account_id: Option<String>,
pub display_name: Option<String>,
pub id: Option<String>,
}Expand description
Details of a Google Analytics property
This type is not used in any activity, and only used as part of another schema.
Fields
analytics_account_id: Option<String>Output only. The ID of the Google Analytics account for the Google Analytics property associated with the specified FirebaseProject.
display_name: Option<String>The display name of the Google Analytics property associated with the specified FirebaseProject.
id: Option<String>The globally unique, Google-assigned identifier of the Google Analytics property associated with the specified FirebaseProject. If you called AddGoogleAnalytics to link the FirebaseProject with a Google Analytics account, the value in this id field is the same as the ID of the property either specified or provisioned with that call to AddGoogleAnalytics.