Struct google_firebase1_beta1::api::AndroidApp[][src]

pub struct AndroidApp {
    pub app_id: Option<String>,
    pub display_name: Option<String>,
    pub name: Option<String>,
    pub package_name: Option<String>,
    pub project_id: Option<String>,
}

Details of a Firebase App for Android.

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

app_id: Option<String>

Immutable. The globally unique, Firebase-assigned identifier for the AndroidApp. This identifier should be treated as an opaque token, as the data format is not specified.

display_name: Option<String>

The user-assigned display name for the AndroidApp.

name: Option<String>

The resource name of the AndroidApp, in the format: projects/ PROJECT_IDENTIFIER/androidApps/APP_ID * PROJECT_IDENTIFIER: the parent Project’s ProjectNumber (recommended) or its ProjectId. Learn more about using project identifiers in Google’s AIP 2510 standard. Note that the value for PROJECT_IDENTIFIER in any response body will be the ProjectId. * APP_ID: the globally unique, Firebase-assigned identifier for the App (see appId).

package_name: Option<String>

Immutable. The canonical package name of the Android app as would appear in the Google Play Developer Console.

project_id: Option<String>

Immutable. A user-assigned unique identifier of the parent FirebaseProject for the AndroidApp.