pub struct AndroidAppConfig {
pub config_file_contents: Option<Vec<u8>>,
pub config_filename: Option<String>,
}Expand description
Configuration metadata of a single Firebase App for Android.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- android apps get config projects (response)
Fields
config_file_contents: Option<Vec<u8>>The contents of the JSON configuration file.
config_filename: Option<String>The filename that the configuration artifact for the AndroidApp is typically saved as. For example: google-services.json