DefaultResources

Struct DefaultResources 

pub struct DefaultResources {
    pub hosting_site: Option<String>,
    pub location_id: Option<String>,
    pub realtime_database_instance: Option<String>,
    pub storage_bucket: Option<String>,
}
DEPRECATED. Auto-provisioning of these resources is changing, so this object no longer reliably provides information about the resources within the Project. Instead, retrieve information about each resource directly from its resource-specific API. The default auto-provisioned resources associated with the Project.

This type is not used in any activity, and only used as part of another schema.

Fields

hosting_site: Option<String>

Output only. DEPRECATED. Instead, find the name of the default Firebase Hosting site using ListSites within the Firebase Hosting REST API. If the default Hosting site for the Project has not yet been provisioned, the return might not contain a default site. The name of the default Firebase Hosting site, in the format: PROJECT_ID Though rare, your projectId might already be used as the name for an existing Hosting site in another project (learn more about creating non-default, additional sites). In these cases, your projectId is appended with a hyphen then five alphanumeric characters to create your default Hosting site name. For example, if your projectId is myproject123, your default Hosting site name might be: myproject123-a5c16

location_id: Option<String>

Output only. DEPRECATED. Instead, use product-specific REST APIs to find the location of each resource in a Project. This field may not be populated, especially for newly provisioned projects after October 30, 2024. The ID of the Project’s “location for default Google Cloud resources”, which are resources associated with Google App Engine. The location is one of the available Google App Engine locations. This field is omitted if the location for default Google Cloud resources has not been set.

realtime_database_instance: Option<String>

Output only. DEPRECATED. Instead, find the name of the default Realtime Database instance using the list endpoint within the Firebase Realtime Database REST API. If the default Realtime Database instance for a Project has not yet been provisioned, the return might not contain a default instance. The default Firebase Realtime Database instance name, in the format: PROJECT_ID Though rare, your projectId might already be used as the name for an existing Realtime Database instance in another project (learn more about database sharding). In these cases, your projectId is appended with a hyphen then five alphanumeric characters to create your default Realtime Database instance name. For example, if your projectId is myproject123, your default database instance name might be: myproject123-a5c16

storage_bucket: Option<String>

Output only. DEPRECATED. Instead, find the name of the default Cloud Storage for Firebase bucket using the list endpoint within the Cloud Storage for Firebase REST API. If the default bucket for the Project has not yet been provisioned, the return might not contain a default bucket. The name of the default Cloud Storage for Firebase bucket, in one of the following formats: * If provisioned before October 30, 2024: PROJECT_ID.firebasestorage.app * If provisioned on or after October 30, 2024: PROJECT_ID.firebasestorage.app