FirebaseAppInfo

Struct FirebaseAppInfo 

pub struct FirebaseAppInfo {
    pub api_key_id: Option<String>,
    pub app_id: Option<String>,
    pub display_name: Option<String>,
    pub expire_time: Option<DateTime<Utc>>,
    pub name: Option<String>,
    pub namespace: Option<String>,
    pub platform: Option<String>,
    pub state: Option<String>,
}
A high-level summary of an App.

This type is not used in any activity, and only used as part of another schema.

Fields

api_key_id: Option<String>

The globally unique, Google-assigned identifier (UID) for the Firebase API key associated with the App. Be aware that this value is the UID of the API key, not the keyString of the API key. The keyString is the value that can be found in the App’s configuration artifact (AndroidApp | IosApp | WebApp). If api_key_id is not set in requests to create the App (AndroidApp | IosApp | WebApp), then Firebase automatically associates an api_key_id with the App. This auto-associated key may be an existing valid key or, if no valid key exists, a new one will be provisioned.

app_id: Option<String>

Output only. Immutable. The globally unique, Firebase-assigned identifier for the WebApp. This identifier should be treated as an opaque token, as the data format is not specified.

display_name: Option<String>

The user-assigned display name of the Firebase App.

expire_time: Option<DateTime<Utc>>

Output only. If the App has been removed from the Project, this is the timestamp of when the App is considered expired and will be permanently deleted. After this time, the App cannot be undeleted (that is, restored to the Project). This value is only provided if the App is in the DELETED state.

name: Option<String>

The resource name of the Firebase App, in the format: projects/PROJECT_ID /iosApps/APP_ID or projects/PROJECT_ID/androidApps/APP_ID or projects/ PROJECT_ID/webApps/APP_ID

namespace: Option<String>

Output only. Immutable. The platform-specific identifier of the App. Note: For most use cases, use appId, which is the canonical, globally unique identifier for referencing an App. This string is derived from a native identifier for each platform: packageName for an AndroidApp, bundleId for an IosApp, and webId for a WebApp. Its contents should be treated as opaque, as the native identifier format may change as platforms evolve. This string is only unique within a FirebaseProject and its associated Apps.

platform: Option<String>

The platform of the Firebase App.

state: Option<String>

Output only. The lifecycle state of the App.