pub struct ListAvailableLocationsResponse {
pub locations: Option<Vec<Location>>,
pub next_page_token: Option<String>,
}Expand description
There is no detailed description.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- available locations list projects (response)
Fields
locations: Option<Vec<Location>>One page of results from a call to ListAvailableLocations.
next_page_token: Option<String>If the result list is too large to fit in a single response, then a token is returned. If the string is empty, then this response is the last page of results and all available locations have been listed. This token can be used in a subsequent call to ListAvailableLocations to find more locations. Page tokens are short-lived and should not be persisted.