pub struct ListShaCertificatesResponse {
pub certificates: Option<Vec<ShaCertificate>>,
}Expand description
There is no detailed description.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- android apps sha list projects (response)
Fields
certificates: Option<Vec<ShaCertificate>>The list of each ShaCertificate associated with the AndroidApp.