pub struct ListWebAppsResponse {
pub apps: Option<Vec<WebApp>>,
pub next_page_token: Option<String>,
}Expand description
There is no detailed description.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- web apps list projects (response)
Fields
apps: Option<Vec<WebApp>>List of each WebApp associated with the specified FirebaseProject.
next_page_token: Option<String>If the result list is too large to fit in a single response, then a token is returned. If the string is empty, then this response is the last page of results. This token can be used in a subsequent call to ListWebApps to find the next group of Apps. Page tokens are short-lived and should not be persisted.