pub struct Location {
pub features: Option<Vec<String>>,
pub location_id: Option<String>,
pub type_: Option<String>,
}Expand description
DEPRECATED. This Location is no longer used to determine Firebase resource locations. Instead, consult product documentation to determine valid locations for each resource used in your Project. A “location for default Google Cloud resources” that can be selected for a FirebaseProject. These are resources associated with Google App Engine.
This type is not used in any activity, and only used as part of another schema.
Fields
features: Option<Vec<String>>Products and services that are available in the location for default Google Cloud resources.
location_id: Option<String>The ID of the Project’s location for default Google Cloud resources. It will be one of the available Google App Engine locations.
type_: Option<String>Indicates whether the location for default Google Cloud resources is a regional or multi-regional location for data replication.