Struct google_firebase1_beta1::api::RemoveAnalyticsRequest [−][src]
There is no detailed description.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- remove analytics projects (request)
Fields
analytics_property_id: Option<String>Optional. The ID of the Google Analytics property associated with the specified FirebaseProject. - If not set, then the Google Analytics property that is currently associated with the specified FirebaseProject is removed. - If set, and the specified FirebaseProject is currently associated with a different Google Analytics property, then the response is a 412 Precondition Failed error.