Struct google_firebase1_beta1::api::WebAppConfig [−][src]
Configuration metadata of a single Firebase App for the web.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- web apps get config projects (response)
Fields
api_key: Option<String>The API key associated with the WebApp.
app_id: Option<String>Immutable. The globally unique, Firebase-assigned identifier for the WebApp.
auth_domain: Option<String>The domain Firebase Auth configures for OAuth redirects, in the format: PROJECT_ID.firebaseapp.com
database_url: Option<String>The default Firebase Realtime Database URL.
location_id: Option<String>The ID of the Project’s default GCP resource location. The location is one of the available GCP resource locations. This field is omitted if the default GCP resource location has not been finalized yet. To set a Project’s default GCP resource location, call FinalizeDefaultLocation after you add Firebase resources to the Project.
measurement_id: Option<String>The unique Google-assigned identifier of the Google Analytics web stream associated with the WebApp. Firebase SDKs use this ID to interact with Google Analytics APIs. This field is only present if the WebApp is linked to a web stream in a Google Analytics App + Web property. Learn more about this ID and Google Analytics web streams in the Analytics documentation. To generate a measurementId and link the WebApp with a Google Analytics web stream, call AddGoogleAnalytics. For apps using the Firebase JavaScript SDK v7.20.0 and later, Firebase dynamically fetches the measurementId when your app initializes Analytics. Having this ID in your config object is optional, but it does serve as a fallback in the rare case that the dynamic fetch fails.
messaging_sender_id: Option<String>The sender ID for use with Firebase Cloud Messaging.
project_id: Option<String>Immutable. A user-assigned unique identifier for the FirebaseProject.
storage_bucket: Option<String>The default Cloud Storage for Firebase storage bucket name.