Struct google_firebase1_beta1::api::AddFirebaseRequest [−][src]
All fields are required.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- add firebase projects (request)
Fields
location_id: Option<String>Deprecated. Instead, to set a Project’s default GCP resource location, call FinalizeDefaultLocation after you add Firebase resources to the GCP Project. The ID of the Project’s default GCP resource location. The location must be one of the available GCP resource locations.
region_code: Option<String>Deprecated. Instead, to link a Project with a Google Analytics account, call AddGoogleAnalytics after you add Firebase resources to the GCP Project. The region code (CLDR) that the account will use for Google Analytics data For example: US, GB, or DE In Java, use com.google.i18n.identifiers.RegionCode.
time_zone: Option<String>Deprecated. Instead, to link a Project with a Google Analytics account, call AddGoogleAnalytics after you add Firebase resources to the GCP Project. The time zone that the account will use for Google Analytics data. For example: America/Los_Angeles or Africa/Abidjan