Struct google_firebase1_beta1::api::FirebaseProject [−][src]
A FirebaseProject is the top-level Firebase entity. It is the container for Firebase Apps, Firebase Hosting sites, storage systems (Firebase Realtime Database, Cloud Firestore, Cloud Storage buckets), and other Firebase and Google Cloud Platform (GCP) resources. You create a FirebaseProject by calling AddFirebase and specifying an existing GCP Project. This adds Firebase resources to the existing GCP Project. Since a FirebaseProject is actually also a GCP Project, a FirebaseProject has the same underlying GCP identifiers (projectNumber and projectId). This allows for easy interop with Google APIs.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- get projects (response)
- patch projects (request|response)
Fields
display_name: Option<String>The user-assigned display name of the Project.
name: Option<String>The resource name of the Project, in the format: projects/PROJECT_IDENTIFIER PROJECT_IDENTIFIER: the Project’s ProjectNumber (recommended) or its ProjectId. Learn more about using project identifiers in Google’s AIP 2510 standard. Note that the value for PROJECT_IDENTIFIER in any response body will be the ProjectId.
project_id: Option<String>Immutable. A user-assigned unique identifier for the Project. This identifier may appear in URLs or names for some Firebase resources associated with the Project, but it should generally be treated as a convenience alias to reference the Project.
project_number: Option<String>Immutable. The globally unique, Google-assigned canonical identifier for the Project. Use this identifier when configuring integrations and/or making API calls to Firebase or third-party services.
resources: Option<DefaultResources>The default Firebase resources associated with the Project.
state: Option<String>Output only. The lifecycle state of the Project. Updates to the state must be performed via com.google.cloudresourcemanager.v1.Projects.DeleteProject and com.google.cloudresourcemanager.v1.Projects.UndeleteProject