pub struct IosAppConfig {
pub config_file_contents: Option<Vec<u8>>,
pub config_filename: Option<String>,
}Expand description
Configuration metadata of a single Firebase App for iOS.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- ios apps get config projects (response)
Fields
config_file_contents: Option<Vec<u8>>The content of the XML configuration file.
config_filename: Option<String>The filename that the configuration artifact for the IosApp is typically saved as. For example: GoogleService-Info.plist