pub struct ListAvailableProjectsResponse {
pub next_page_token: Option<String>,
pub project_info: Option<Vec<ProjectInfo>>,
}Expand description
There is no detailed description.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- list available projects (response)
Fields
next_page_token: Option<String>If the result list is too large to fit in a single response, then a token is returned. If the string is empty, then this response is the last page of results. This token can be used in a subsequent calls to ListAvailableProjects to find the next group of Projects. Page tokens are short-lived and should not be persisted.
project_info: Option<Vec<ProjectInfo>>The list of Google Cloud Projects which can have Firebase resources added to them.