pub struct ProjectInfo {
pub display_name: Option<String>,
pub location_id: Option<String>,
pub project: Option<String>,
}Expand description
A reference to a Google Cloud Project.
This type is not used in any activity, and only used as part of another schema.
Fields
display_name: Option<String>The user-assigned display name of the Google Cloud Project, for example: My App.
location_id: Option<String>DEPRECATED Instead, use product-specific REST APIs to work with the location of each resource in a Project. This field may not be populated, especially for newly provisioned projects after October 30, 2024. The ID of the Project’s “location for default Google Cloud resources”. The location is one of the available Google App Engine locations. Not all Projects will have this field populated. If it is not populated, it means that the Project does not yet have a location for default Google Cloud resources.
project: Option<String>The resource name of the Google Cloud Project to which Firebase resources can be added, in the format: projects/PROJECT_IDENTIFIER Refer to the FirebaseProject name field for details about PROJECT_IDENTIFIER values.