pub struct StreamMapping {
pub app: Option<String>,
pub measurement_id: Option<String>,
pub stream_id: Option<i64>,
}Expand description
A mapping of a Firebase App to a Google Analytics data stream
This type is not used in any activity, and only used as part of another schema.
Fields
app: Option<String>The resource name of the Firebase App associated with the Google Analytics data stream, in the format: projects/PROJECT_IDENTIFIER/androidApps/APP_ID or projects/PROJECT_IDENTIFIER/iosApps/APP_ID or projects/PROJECT_IDENTIFIER /webApps/APP_ID Refer to the FirebaseProject name field for details about PROJECT_IDENTIFIER values.
measurement_id: Option<String>Applicable for Firebase Web Apps only. The unique Google-assigned identifier of the Google Analytics web stream associated with the Firebase Web App. Firebase SDKs use this ID to interact with Google Analytics APIs. Learn more about this ID and Google Analytics web streams in the Analytics documentation.
stream_id: Option<i64>The unique Google-assigned identifier of the Google Analytics data stream associated with the Firebase App. Learn more about Google Analytics data streams in the Analytics documentation.