WebAppConfig

Struct WebAppConfig 

pub struct WebAppConfig {
    pub api_key: Option<String>,
    pub app_id: Option<String>,
    pub auth_domain: Option<String>,
    pub database_url: Option<String>,
    pub location_id: Option<String>,
    pub measurement_id: Option<String>,
    pub messaging_sender_id: Option<String>,
    pub project_id: Option<String>,
    pub project_number: Option<String>,
    pub realtime_database_url: Option<String>,
    pub storage_bucket: Option<String>,
    pub version: Option<String>,
}
Configuration metadata of a single Firebase App for the web.

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

api_key: Option<String>

The keyString of the API key associated with the WebApp. Note that this value is not the apiKeyId (the UID) of the API key associated with the WebApp.

app_id: Option<String>

Immutable. The globally unique, Firebase-assigned identifier for the WebApp.

auth_domain: Option<String>

The domain Firebase Auth configures for OAuth redirects, in the format: PROJECT_ID.firebaseapp.com

database_url: Option<String>

DEPRECATED. Instead, find the URL of the default Realtime Database instance using the list endpoint within the Firebase Realtime Database REST API. If the default instance for the Project has not yet been provisioned, the return might not contain a default instance. Note that the config that’s generated for the Firebase console or the Firebase CLI uses the Realtime Database endpoint to populate this value for that config. The URL of the default Firebase Realtime Database instance.

location_id: Option<String>

DEPRECATED. Instead, use product-specific REST APIs to find the location of each resource in a Project. This field may not be populated, especially for newly provisioned projects after October 30, 2024. The ID of the Project’s “location for default Google Cloud resources”, which are resources associated with Google App Engine. The location is one of the available App Engine locations. This field is omitted if the location for default Google Cloud resources has not been set.

measurement_id: Option<String>

The unique Google-assigned identifier of the Google Analytics web stream associated with the WebApp. Firebase SDKs use this ID to interact with Google Analytics APIs. This field is only present if the WebApp is linked to a web stream in a Google Analytics App + Web property. Learn more about this ID and Google Analytics web streams in the Analytics documentation. To generate a measurementId and link the WebApp with a Google Analytics web stream, call AddGoogleAnalytics. For apps using the Firebase JavaScript SDK v7.20.0 and later, Firebase dynamically fetches the measurementId when your app initializes Analytics. Having this ID in your config object is optional, but it does serve as a fallback in the rare case that the dynamic fetch fails.

messaging_sender_id: Option<String>

The sender ID for use with Firebase Cloud Messaging.

project_id: Option<String>

Immutable. A user-assigned unique identifier for the FirebaseProject.

project_number: Option<String>

Output only. Immutable. The globally unique, Google-assigned canonical identifier for the Project. Use this identifier when configuring integrations and/or making API calls to Google Cloud or third-party services.

realtime_database_url: Option<String>

Optional. Duplicate field for the URL of the default Realtime Database instances (if the default instance has been provisioned). If the request asks for the V2 config format, this field will be populated instead of realtime_database_instance_uri.

storage_bucket: Option<String>

DEPRECATED. Instead, find the name of the default Cloud Storage for Firebase bucket using the list endpoint within the Cloud Storage for Firebase REST API. If the default bucket for the Project has not yet been provisioned, the return might not contain a default bucket. Note that the config that’s generated for the Firebase console or the Firebase CLI uses the Cloud Storage for Firebase endpoint to populate this value for that config. The name of the default Cloud Storage for Firebase bucket.

version: Option<String>

Version of the config specification.